=== modified file 'drizzled/plugin/client/concurrent.h'
--- drizzled/plugin/client/concurrent.h	2011-03-14 05:40:28 +0000
+++ drizzled/plugin/client/concurrent.h	2011-05-20 21:45:26 +0000
@@ -20,6 +20,7 @@
 #pragma once
 
 #include <drizzled/plugin/client.h>
+#include <drizzled/util/string.h>
 #include <boost/tokenizer.hpp>
 #include <vector>
 #include <queue>
@@ -37,11 +38,10 @@
  */
 class Concurrent: public Client
 {
-  typedef std::vector<char> Bytes;
-  typedef std::queue <Bytes> Queue;
+  typedef std::queue < drizzled::util::String > Queue;
   Queue to_execute;
   bool is_dead;
-  Bytes packet_buffer;
+  drizzled::util::String packet_buffer;
 
 public:
 
@@ -63,11 +63,9 @@
     while(not to_execute.empty())
     {
       Queue::value_type next= to_execute.front();
-      packet_buffer.resize(next.size());
-      memcpy(&packet_buffer[0], &next[0], next.size());
-
-      *packet= &packet_buffer[0];
-
+      packet_buffer.assign(next.c_str(), next.size());
+
+      *packet= packet_buffer.c_str();
       *packet_length= next.size();
 
       to_execute.pop();
@@ -77,9 +75,9 @@
 
     if (not is_dead)
     {
-      packet_buffer.resize(1);
+      packet_buffer.clear();
       *packet_length= 1;
-      *packet= &packet_buffer[0];
+      *packet= packet_buffer.c_str();
       is_dead= true;
 
       return true;
@@ -110,29 +108,28 @@
 
   void pushSQL(const std::string &arg)
   {
-    Bytes byte;
     typedef boost::tokenizer<boost::escaped_list_separator<char> > Tokenizer;
     Tokenizer tok(arg, boost::escaped_list_separator<char>("\\", ";", "\""));
 
     {
-      byte.resize(sizeof("START TRANSACTION")); // +1 for the COM_QUERY, provided by null count from sizeof()
-      byte[0]= COM_QUERY;
-      memcpy(&byte[1], "START TRANSACTION", sizeof("START TRANSACTION") -1);
+      drizzled::util::String byte;
+      byte.assign(1, char(COM_QUERY)); // Insert our COM_QUERY
+      byte.append(drizzle_literal_parameter("START TRANSACTION")); // +1 for the COM_QUERY, provided by null count from sizeof()
       to_execute.push(byte);
     }
 
     for (Tokenizer::iterator iter= tok.begin(); iter != tok.end(); ++iter)
     {
-      byte.resize(iter->size() +1); // +1 for the COM_QUERY
-      byte[0]= COM_QUERY;
-      memcpy(&byte[1], iter->c_str(), iter->size());
+      drizzled::util::String byte;
+      byte.assign(1, char(COM_QUERY)); // Insert our COM_QUERY
+      byte.append(iter->c_str(), iter->size());
       to_execute.push(byte);
     }
 
     {
-      byte.resize(sizeof("COMMIT")); // +1 for the COM_QUERY, provided by null count from sizeof()
-      byte[0]= COM_QUERY;
-      memcpy(&byte[1], "COMMIT", sizeof("COMMIT") -1);
+      drizzled::util::String byte;
+      byte.assign(1, char(COM_QUERY)); // Insert our COM_QUERY
+      byte.append(drizzle_literal_parameter("COMMIT")); // +1 for the COM_QUERY, provided by null count from sizeof()
       to_execute.push(byte);
     }
   }

=== modified file 'drizzled/util/string.h'
--- drizzled/util/string.h	2011-04-08 14:46:29 +0000
+++ drizzled/util/string.h	2011-05-20 21:45:26 +0000
@@ -44,6 +44,8 @@
 #include <boost/functional/hash.hpp>
 #include <boost/shared_ptr.hpp>
 
+#define drizzle_literal_parameter(X) (X), size_t((sizeof(X) - 1))
+
 namespace drizzled {
 namespace util {
 
@@ -77,6 +79,82 @@
   }
 };
 
+class String
+{
+public:
+
+  String()
+  {
+    _bytes.resize(1);
+  }
+
+  const char *c_str() const
+  {
+    return &_bytes[0];
+  }
+
+  char *c_str()
+  {
+    return &_bytes[0];
+  }
+
+  void assign(const size_t repeat, const char arg)
+  {
+    _bytes.resize(repeat +1); // inserts NULL at end
+    memset(&_bytes[0], int(arg), repeat);
+    _bytes[repeat]= 0;
+  }
+
+  void assign(const char *arg, const size_t arg_size)
+  {
+    _bytes.resize(arg_size +1); // +1 for NULL
+    memcpy(&_bytes[0], arg, arg_size);
+    _bytes[arg_size]= 0;
+  }
+
+  void append(const char *arg, const size_t arg_size)
+  {
+    if (not arg or not arg_size)
+      return;
+
+    size_t original_size= size();
+    if (original_size)
+    {
+      _bytes.resize(original_size +arg_size +1); // inserts NULL since string will already have a NULL
+      memcpy(&_bytes[original_size], arg, arg_size);
+      _bytes[original_size +arg_size]= 0;
+    }
+    else
+    {
+      assign(arg, arg_size);
+    }
+  }
+
+  const char& operator[] (size_t arg) const
+  {
+    return _bytes[arg];
+  }
+
+  char& operator[] (size_t arg)
+  {
+    return _bytes[arg];
+  }
+
+  void clear()
+  {
+    _bytes.resize(1);
+    _bytes[0]= 0;
+  }
+
+  size_t size() const
+  {
+    return _bytes.size() -1;
+  }
+
+private:
+  std::vector<char> _bytes;
+};
+
 } /* namespace util */
 } /* namespace drizzled */
 

=== modified file 'tests/include.am'
--- tests/include.am	2011-03-15 16:21:13 +0000
+++ tests/include.am	2011-05-20 21:45:26 +0000
@@ -135,6 +135,9 @@
 test-drizzle: 
 	( $(MAKE) $(AM_MAKEFLAGS) && cd tests && $(TEST_RUN) $(TEST_RUN_EXTRA_OPTIONS) --fast --force --suite=$(NORMAL_TESTS))
 
+gdb-drizzled: 
+	./libtool --mode=execute gdb ./drizzled/drizzled
+
 test-valgrind: 
 	( $(MAKE) $(AM_MAKEFLAGS) && cd tests && $(TEST_RUN) $(TEST_RUN_EXTRA_OPTIONS) --valgrind --force --suite=$(NORMAL_TESTS) && python strip-valgrind)
 

